@@ -4,6 +4,18 @@ from net_file.net_file import open_url
 
 
 def tutorial():
+    with open_url(
+            url='sftp://10.16.10.184/media/data/prepared_datasets/27.12_bord_real/video/02d87f31-ab38-43ae-9d28-bb256c725192.mp4',
+            start_bytes=500 * 1024 * 1024,
+            length=5 * 1024 * 1024,
+            host_auth={'10.16.10.184': ('polylog_build', 'Gjkbkju-25stc')},
+    ) as open_file:
+        content = open_file.read(32768)
+        while content:
+            print(len(content))
+            content = open_file.read()
+        print(len(content))
+
     with open_url(
             url='http://10.16.10.131:8888/storage/prepared_datasets/27.12_bord_real/video/02d87f31-ab38-43ae-9d28-bb256c725192.mp4',
             start_bytes=10000,
